package de.intevation.flys.importer;

import java.util.ArrayList;
import java.util.List;

import org.apache.log4j.Logger;

import org.hibernate.Session;
import org.hibernate.Query;

import de.intevation.flys.model.River;
import de.intevation.flys.model.Unit;
import de.intevation.flys.model.Waterlevel;


public class ImportWaterlevel {

    private static final Logger log = Logger.getLogger(ImportWaterlevel.class);

    private ImportUnit unit;

    private String description;

    private List<ImportWaterlevelQRange> qRanges;

    private Waterlevel peer;

    public ImportWaterlevel(String description) {
        this.qRanges = new ArrayList<ImportWaterlevelQRange>();

        this.description = description;
    }

    public String getDescription() {
        return this.description;
    }

    public void setUnit(ImportUnit unit) {
        this.unit = unit;
    }

    public ImportUnit getUnit() {
        return this.unit;
    }

    public void addValue(ImportWaterlevelQRange qRange) {
        this.qRanges.add(qRange);
    }

    public List<ImportWaterlevelQRange> getQRanges() {
        return this.qRanges;
    }

    public void storeDependencies(River river) {
        log.info("store dependencies");

        Waterlevel peer = getPeer(river);

        if (peer != null) {
            int i = 0;

            for (ImportWaterlevelQRange qRange : qRanges) {
                qRange.storeDependencies(peer);
                i++;
            }

            log.info("stored " + i + " waterlevel q ranges");
        }
    }

    public Waterlevel getPeer(River river) {
        Unit u = unit != null ? unit.getPeer() : null;
        if (u == null) {
            log.warn("skip invalid waterlevel - no unit set!");
            return null;
        }

        if (peer == null) {
            Session session = ImporterSession.getInstance()
                .getDatabaseSession();
            Query query = session.createQuery("from Waterlevel where "
                + "   river=:river and " + "   unit=:unit and "
                + "   description=:description");

            query.setParameter("river", river);
            query.setParameter("unit", u);
            query.setParameter("description", description);

            List<Waterlevel> wsts = query.list();
            if (wsts.isEmpty()) {
                peer = new Waterlevel(river, u, description);
                session.save(peer);
            }
            else {
                peer = wsts.get(0);
            }
        }

        return peer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
